#
# spec file for package libcaes
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname	libcaes1
Name:           libcaes
Version:        20230406
Release:        bp156.1.5
Summary:        Library for AES encryption
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libcaes
Source:         https://github.com/libyal/libcaes/releases/download/%version/libcaes-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libcaes/releases/download/%version/libcaes-alpha-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(openssl) >= 1.0
%{python_subpackages}
# Various notes: https://en.opensuse.org/libyal

%description
libcaes is a library for AES encryption.

%package -n %lname
Summary:        Library for AES encryption
Group:          System/Libraries

%description -n %lname
libcaes is a library for AES encryption.

%package devel
Summary:        Development files for libcaes, a AES encryption library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libcaes is a library for AES encryption.

This subpackage contains libraries and header files for developing
applications that want to make use of libcaes.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-python PYTHON_VERSION="%{$python_bin_suffix}" LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log || exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find "%buildroot" -name "*.la" -print -delete

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libcaes.so.1*

%files -n %name-devel
%_includedir/libcaes*
%_libdir/libcaes.so
%_libdir/pkgconfig/libcaes.pc
%_mandir/man3/libcaes.3*

%files %python_files
%python_sitearch/*

%changelog
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Fri Apr  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230406
  * No changelog was provided
* Sun Nov 27 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221127
  * Detection for EVP_CipherInit_ex during build was not accurate
    and libcaes features depending on it would be skipped.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symver
* Sun May 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220529
  * OpenSSL 3 support
* Mon Apr 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220424
  * No changelog was provided
* Thu Jan 20 2022 Jan Engelhardt <jengelh@inai.de>
- Transform specfile to emit python multiversion packages.
* Thu Nov 25 2021 Jan Engelhardt <jengelh@inai.de>
- Add keyring
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210522
  * No changelog was provided
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210412 (f0b06e5c)
  * No changelog was provided
- Add system-libs.patch
- Enable python3 integration
* Sun Dec 27 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201012
  * worked on AES-CFB support and tests
  * provide OpenSSL error information
* Tue Apr  2 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190102
  * Added OpenSSL EVP AES-XTS support
  * Removed WinCrypt support (deprecated)
* Sun Oct  1 2017 Greg.Freemyer@gmail.com
- update to v0~20170110
  * applied 2017 updates
  * code clean up
  * worked on tests
* Fri Jan  9 2015 Greg.Freemyer@gmail.com
- update to v0~20150101
  * 2015 update - minimal changes
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcstring from OBS, not internal version
- remove %%if for opensuse.  Not needed with libyal consolidated in security:forensics
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- update to 0~20140731
  * Added HAVE_DLLMAIN support
  * 2014 update
  * updated dependencies
  * fixed issue not freeing error state memory allocated by EVP
  * worked on tests
  * worked on moving XTS support from libfvde
  * textual changes
- remove use of xz compression to simplify tarball download
* Fri Aug  2 2013 Greg.Freemyer@gmail.com
- update DL-URL
- use factory package for libcerror if available
* Fri Apr  5 2013 jengelh@inai.de
- Initial package (version 0~20130331) for build.opensuse.org
